import { RemovalPolicy, aws_lambda as lambda } from 'aws-cdk-lib';
import { Construct } from 'constructs';
export interface DeploymentSettings {
    readonly maxNumAttempts?: number;
    readonly deploymentArchitecture?: lambda.Architecture;
}
export declare enum PodInstanceType {
    S1 = "s1",
    P1 = "p1",
    P2 = "p2"
}
export declare enum PodInstanceSize {
    X1 = "x1",
    X2 = "x2",
    X4 = "x4",
    X8 = "x8"
}
export declare enum DistanceMetric {
    EUCLIDEAN = "euclidean",
    COSINE = "cosine",
    DOT_PRODUCT = "dotproduct"
}
export declare enum PineConeEnvironment {
    GCP_STARTER = "gcp-starter",
    GCP_FREE_US_WEST_1 = "us-west1-gcp-free",
    GCP_FREE_ASIA_SOUTHEAST_1 = "asia-southeast1-gcp-free",
    GCP_FREE_US_WEST_4 = "us-west4-gcp-free",
    GCP_STD_US_WEST_1 = "us-west1-gcp",
    GCP_STD_US_CENTRAL_1 = "us-central1-gcp",
    GCP_STD_US_WEST_4 = "us-west4-gcp",
    GCP_STD_US_EAST_4 = "us-east4-gcp",
    GCP_STD_NORTH_AMERICA_NORTHEAST_1 = "northamerica-northeast1-gcp",
    GCP_STD_ASIA_NORTHEAST_1 = "asia-northeast1-gcp",
    GCP_STD_ASIA_SOUTHEAST_1 = "asia-southeast1-gcp",
    GCP_STD_US_EAST_1 = "us-east1-gcp",
    GCP_STD_EU_WEST_1 = "eu-west1-gcp",
    GCP_STD_EU_WEST_4 = "eu-west4-gcp",
    AWS_STD_US_EAST_1 = "us-east-1-aws",
    AZURE_STD_EAST_US = "eastus-azure"
}
export declare enum CloudProvider {
    AWS = "aws"
}
export declare enum Region {
    US_WEST_2 = "us-west-2"
}
export interface MetaDataConfig {
    readonly indexed: string[];
}
export interface PodSpec {
    readonly environment: PineConeEnvironment;
    readonly numReplicas?: number;
    readonly shards?: number;
    readonly numPods?: number;
    readonly podInstanceType?: PodInstanceType;
    readonly podInstanceSize?: PodInstanceSize;
    readonly metaDataConfig?: MetaDataConfig;
}
export interface ServerlessSpec {
    readonly cloudProvider: CloudProvider;
    readonly region: Region;
}
export interface PineconeIndexSettings {
    readonly apiKeySecretName: string;
    readonly dimension: number;
    readonly podSpec: PodSpec | ServerlessSpec;
    readonly name?: string;
    readonly removalPolicy?: RemovalPolicy;
    readonly metric?: DistanceMetric;
}
export interface PineconeIndexProps {
    readonly indexSettings: PineconeIndexSettings[];
    readonly deploymentSettings?: DeploymentSettings;
}
export declare class PineconeIndex extends Construct {
    private stackName;
    private deploymentSettings;
    constructor(scope: Construct, id: string, props: PineconeIndexProps);
    private convertCamelToEnvVarName;
    private createCustomResource;
    private createLambdaFunction;
    private getIndexName;
    private dumpToEnv;
    private serializeEnv;
    private getHashForAllFilesInDir;
}
